pub struct GoogleIamAdminV1WorkforcePoolProviderOidcWebSsoConfig {
pub additional_scopes: Option<Vec<String>>,
pub assertion_claims_behavior: Option<String>,
pub response_type: Option<String>,
}Expand description
Configuration for web single sign-on for the OIDC provider.
This type is not used in any activity, and only used as part of another schema.
Fields
additional_scopes: Option<Vec<String>>Optional. Additional scopes to request for in the OIDC authentication request on top of scopes requested by default. By default, the openid, profile and email scopes that are supported by the identity provider are requested. Each additional scope may be at most 256 characters. A maximum of 10 additional scopes may be configured.
assertion_claims_behavior: Option<String>Required. The behavior for how OIDC Claims are included in the assertion object used for attribute mapping and attribute condition.
response_type: Option<String>Required. The Response Type to request for in the OIDC Authorization Request for web sign-in. The CODE Response Type is recommended to avoid the Implicit Flow, for security reasons.