pub struct LintResult {
pub debug_message: Option<String>,
pub field_name: Option<String>,
pub level: Option<String>,
pub location_offset: Option<i32>,
pub severity: Option<String>,
pub validation_unit_name: Option<String>,
}Expand description
Structured response of a single validation unit.
This type is not used in any activity, and only used as part of another schema.
Fields
debug_message: Option<String>Human readable debug message associated with the issue.
field_name: Option<String>The name of the field for which this lint result is about. For nested messages field_name consists of names of the embedded fields separated by period character. The top-level qualifier is the input object to lint in the request. For example, the field_name value condition.expression identifies a lint result for the expression field of the provided condition.
level: Option<String>The validation unit level.
location_offset: Option<i32>0-based character position of problematic construct within the object identified by field_name. Currently, this is populated only for condition expression.
severity: Option<String>The validation unit severity.
validation_unit_name: Option<String>The validation unit name, for instance “lintValidationUnits/ConditionComplexityCheck”.