pub struct ListAttestationRulesResponse {
pub attestation_rules: Option<Vec<AttestationRule>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListAttestationRules.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
attestation_rules: Option<Vec<AttestationRule>>A list of AttestationRules.
next_page_token: Option<String>Optional. A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.