pub struct ListWorkforcePoolProviderScimTenantsResponse {
pub next_page_token: Option<String>,
pub workforce_pool_provider_scim_tenants: Option<Vec<WorkforcePoolProviderScimTenant>>,
}Expand description
Gemini Enterprise only. Response message for ListWorkforcePoolProviderScimTenants.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>Optional. Gemini Enterprise only. A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
workforce_pool_provider_scim_tenants: Option<Vec<WorkforcePoolProviderScimTenant>>Output only. Gemini Enterprise only. A list of SCIM tenants.