pub struct ListWorkloadIdentityPoolManagedIdentitiesResponse {
pub next_page_token: Option<String>,
pub workload_identity_pool_managed_identities: Option<Vec<WorkloadIdentityPoolManagedIdentity>>,
}Expand description
Response message for ListWorkloadIdentityPoolManagedIdentities.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
workload_identity_pool_managed_identities: Option<Vec<WorkloadIdentityPoolManagedIdentity>>A list of managed identities.