pub struct OauthClientCredential {
pub client_secret: Option<String>,
pub disabled: Option<bool>,
pub display_name: Option<String>,
pub name: Option<String>,
}Expand description
Represents an OauthClientCredential. Used to authenticate an OauthClient while accessing Google Cloud resources on behalf of a user by using OAuth 2.0 Protocol.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations oauth clients credentials create projects (request|response)
- locations oauth clients credentials get projects (response)
- locations oauth clients credentials patch projects (request|response)
Fields
client_secret: Option<String>Output only. The system-generated OAuth client secret. The client secret must be stored securely. If the client secret is leaked, you must delete and re-create the client credential. To learn more, see OAuth client and credential security risks and mitigations
disabled: Option<bool>Optional. Whether the OauthClientCredential is disabled. You cannot use a disabled OauthClientCredential.
display_name: Option<String>Optional. A user-specified display name of the OauthClientCredential. Cannot exceed 32 characters.
name: Option<String>Immutable. Identifier. The resource name of the OauthClientCredential. Format: projects/{project}/locations/{location}/oauthClients/{oauth_client}/credentials/{credential}