[][src]Struct google_iam1::EnableServiceAccountRequest

pub struct EnableServiceAccountRequest { /* fields omitted */ }

The service account enable request.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).