[][src]Struct google_iam1::ListServiceAccountKeysResponse

pub struct ListServiceAccountKeysResponse {
    pub keys: Option<Vec<ServiceAccountKey>>,
}

The service account keys list response.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

keys: Option<Vec<ServiceAccountKey>>

The public keys for the service account.