[][src]Struct google_iam1::PatchServiceAccountRequest

pub struct PatchServiceAccountRequest {
    pub service_account: Option<ServiceAccount>,
    pub update_mask: Option<String>,
}

The request for PatchServiceAccount.

You can patch only the display_name and description fields. You must use the update_mask field to specify which of these fields you want to patch.

Only the fields specified in the request are guaranteed to be returned in the response. Other fields may be empty in the response.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

service_account: Option<ServiceAccount>

no description provided

update_mask: Option<String>

no description provided