[][src]Struct google_iam1::QueryTestablePermissionsRequest

pub struct QueryTestablePermissionsRequest {
    pub page_token: Option<String>,
    pub full_resource_name: Option<String>,
    pub page_size: Option<i32>,
}

A request to get permissions which can be tested on a resource.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

page_token: Option<String>

Optional pagination token returned in an earlier QueryTestablePermissionsRequest.

full_resource_name: Option<String>

Required. The full resource name to query from the list of testable permissions.

The name follows the Google Cloud Platform resource format. For example, a Cloud Platform project with id my-project will be named //cloudresourcemanager.googleapis.com/projects/my-project.

page_size: Option<i32>

Optional limit on the number of permissions to include in the response.

The default is 100, and the maximum is 1,000.