[][src]Struct google_iam1::QueryTestablePermissionsResponse

pub struct QueryTestablePermissionsResponse {
    pub next_page_token: Option<String>,
    pub permissions: Option<Vec<Permission>>,
}

The response containing permissions which can be tested on a resource.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

next_page_token: Option<String>

To retrieve the next page of results, set QueryTestableRolesRequest.page_token to this value.

permissions: Option<Vec<Permission>>

The Permissions testable on the requested resource.