[][src]Struct google_iam1::ServiceAccount

pub struct ServiceAccount {
    pub oauth2_client_id: Option<String>,
    pub display_name: Option<String>,
    pub description: Option<String>,
    pub project_id: Option<String>,
    pub disabled: Option<bool>,
    pub etag: Option<String>,
    pub unique_id: Option<String>,
    pub email: Option<String>,
    pub name: Option<String>,
}

An IAM service account.

A service account is an account for an application or a virtual machine (VM) instance, not a person. You can use a service account to call Google APIs. To learn more, read the overview of service accounts.

When you create a service account, you specify the project ID that owns the service account, as well as a name that must be unique within the project. IAM uses these values to create an email address that identifies the service account.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

oauth2_client_id: Option<String>

Output only. The OAuth 2.0 client ID for the service account.

display_name: Option<String>

Optional. A user-specified, human-readable name for the service account. The maximum length is 100 UTF-8 bytes.

description: Option<String>

Optional. A user-specified, human-readable description of the service account. The maximum length is 256 UTF-8 bytes.

project_id: Option<String>

Output only. The ID of the project that owns the service account.

disabled: Option<bool>

Output only. Whether the service account is disabled.

etag: Option<String>

Deprecated. Do not use.

unique_id: Option<String>

Output only. The unique, stable numeric ID for the service account.

Each service account retains its unique ID even if you delete the service account. For example, if you delete a service account, then create a new service account with the same name, the new service account has a different unique ID than the deleted service account.

email: Option<String>

Output only. The email address of the service account.

name: Option<String>

The resource name of the service account.

Use one of the following formats:

  • projects/{PROJECT_ID}/serviceAccounts/{EMAIL_ADDRESS}
  • projects/{PROJECT_ID}/serviceAccounts/{UNIQUE_ID}

As an alternative, you can use the - wildcard character instead of the project ID:

  • projects/-/serviceAccounts/{EMAIL_ADDRESS}
  • projects/-/serviceAccounts/{UNIQUE_ID}

When possible, avoid using the - wildcard character, because it can cause response messages to contain misleading error codes. For example, if you try to get the service account projects/-/serviceAccounts/fake@example.com, which does not exist, the response contains an HTTP 403 Forbidden error instead of a 404 Not Found error.