[][src]Struct google_iam1::UploadServiceAccountKeyRequest

pub struct UploadServiceAccountKeyRequest {
    pub public_key_data: Option<String>,
}

The service account key upload request.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

public_key_data: Option<String>

A field that allows clients to upload their own public key. If set, use this public key data to create a service account key for given service account. Please note, the expected format for this field is X509_PEM.