Struct google_iam1::api::CreateRoleRequest [−][src]
The request to create a new role.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- roles create organizations (request)
- roles create projects (request)
Fields
role: Option<Role>The Role resource to create.
role_id: Option<String>The role ID to use for this role. A role ID may contain alphanumeric characters, underscores (_), and periods (.). It must contain a minimum of 3 characters and a maximum of 64 characters.