Struct google_iam1::api::Role [−][src]
A role in the Identity and Access Management API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- roles create organizations (response)
- roles delete organizations (response)
- roles get organizations (response)
- roles patch organizations (request|response)
- roles undelete organizations (response)
- roles create projects (response)
- roles delete projects (response)
- roles get projects (response)
- roles patch projects (request|response)
- roles undelete projects (response)
- get roles (response)
- list roles (none)
- query grantable roles roles (none)
Fields
deleted: Option<bool>The current deleted state of the role. This field is read only. It will be ignored in calls to CreateRole and UpdateRole.
description: Option<String>Optional. A human-readable description for the role.
etag: Option<String>Used to perform a consistent read-modify-write.
included_permissions: Option<Vec<String>>The names of the permissions this role grants when bound in an IAM policy.
name: Option<String>The name of the role. When Role is used in CreateRole, the role name must not be set. When Role is used in output and other input such as UpdateRole, the role name is the complete path, e.g., roles/logging.viewer for predefined roles and organizations/{ORGANIZATION_ID}/roles/logging.viewer for custom roles.
stage: Option<String>The current launch stage of the role. If the ALPHA launch stage has been selected for a role, the stage field will not be included in the returned definition for the role.
title: Option<String>Optional. A human-readable title for the role. Typically this is limited to 100 UTF-8 bytes.