pub struct WorkforcePoolProviderScimTenant {
pub base_uri: Option<String>,
pub claim_mapping: Option<HashMap<String, String>>,
pub description: Option<String>,
pub display_name: Option<String>,
pub name: Option<String>,
pub purge_time: Option<DateTime<Utc>>,
pub service_agent: Option<String>,
pub state: Option<String>,
}Expand description
Gemini Enterprise only. Represents a SCIM tenant. Used for provisioning and managing identity data (such as Users and Groups) in cross-domain environments.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- workforce pools providers scim tenants create locations (request|response)
- workforce pools providers scim tenants delete locations (response)
- workforce pools providers scim tenants get locations (response)
- workforce pools providers scim tenants patch locations (request|response)
- workforce pools providers scim tenants undelete locations (response)
Fields
base_uri: Option<String>Output only. Gemini Enterprise only. Represents the base URI as defined in RFC 7644, Section 1.3. Clients must use this as the root address for managing resources under the tenant. Format: https://iamscim.googleapis.com/{version}/{tenant_id}/
claim_mapping: Option<HashMap<String, String>>Required. Immutable. Gemini Enterprise only. Maps SCIM attributes to Google attributes. This mapping is used to associate the attributes synced via SCIM with the Google Cloud attributes used in IAM policies for Workforce Identity Federation. SCIM-managed user and group attributes are mapped to google.subject and google.group respectively. Each key must be a string specifying the Google Cloud IAM attribute to map to. The supported keys are as follows: * google.subject: The principal IAM is authenticating. You can reference this value in IAM bindings. This is also the subject that appears in Cloud Logging logs. This is a required field and the mapped subject cannot exceed 127 bytes. * google.group: Group the authenticating user belongs to. You can grant group access to resources using an IAM principalSet binding; access applies to all members of the group. Each value must be a [Common Expression Language] (https://opensource.google/projects/cel) expression that maps SCIM user or group attribute to the normalized attribute specified by the corresponding map key. Example: To map the SCIM user’s externalId to google.subject and the SCIM group’s externalId to google.group: { "google.subject": "user.externalId", "google.group": "group.externalId" }
description: Option<String>Optional. Gemini Enterprise only. The description of the SCIM tenant. Cannot exceed 256 characters.
display_name: Option<String>Optional. Gemini Enterprise only. The display name of the SCIM tenant. Cannot exceed 32 characters.
name: Option<String>Identifier. Gemini Enterprise only. The resource name of the SCIM Tenant. Format: locations/{location}/workforcePools/{workforce_pool}/providers/ {workforce_pool_provider}/scimTenants/{scim_tenant}
purge_time: Option<DateTime<Utc>>Output only. Gemini Enterprise only. The timestamp that represents the time when the SCIM tenant is purged.
service_agent: Option<String>Output only. Service Agent created by SCIM Tenant API. SCIM tokens created under this tenant will be attached to this service agent.
state: Option<String>Output only. Gemini Enterprise only. The state of the tenant.