Struct google_iam1::api::WorkloadIdentityPool [−][src]
Represents a collection of external workload identities. You can define IAM policies to grant these identities access to Google Cloud resources.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
description: Option<String>A description of the pool. Cannot exceed 256 characters.
disabled: Option<bool>Whether the pool is disabled. You cannot use a disabled pool to exchange tokens, or use existing tokens to access resources. If the pool is re-enabled, existing tokens grant access again.
display_name: Option<String>A display name for the pool. Cannot exceed 32 characters.
name: Option<String>Output only. The resource name of the pool.
state: Option<String>Output only. The state of the pool.