Struct google_iam1::CreateServiceAccountKeyRequest [] [src]

pub struct CreateServiceAccountKeyRequest {
    pub private_key_type: Option<String>,
    pub include_public_key_data: Option<bool>,
    pub key_algorithm: Option<String>,
}

The service account key create request.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

The output format of the private key. GOOGLE_CREDENTIALS_FILE is the default output format.

no description provided

Which type of key and algorithm to use for the key. The default is currently a 2K RSA key. However this may change in the future.