[−][src]Struct google_iam1::QueryAuditableServicesResponse
A response containing a list of auditable services for a resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- query auditable services iam policies (response)
Fields
services: Option<Vec<AuditableService>>The auditable services for a resource.