[−][src]Struct google_iam1::SignJwtRequest
The service account sign JWT request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- service accounts sign jwt projects (request)
Fields
payload: Option<String>Required. The JWT payload to sign. Must be a serialized JSON object that contains a
JWT Claims Set. For example: {"sub": "user@example.com", "iat": 313435}
If the JWT Claims Set contains an expiration time (exp) claim, it must be
an integer timestamp that is not in the past and no more than 1 hour in the
future.
If the JWT Claims Set does not contain an expiration time (exp) claim,
this claim is added automatically, with a timestamp that is 1 hour in the
future.